==> dev0s-3.2.3.tar.gz: dev0s-3.2.3/dev0s/classes/requests/__init__.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# imports.
from dev0s.classes.response import *
from dev0s.classes import objects

# pip imports.
import urllib
import requests as __requests__

# the requests class.
class Requests():

	# variables.
	https = True
	allow_redirects = True

	# utils.
	def encode(data):
		return f"?{urllib.parse.urlencode(data)}"
		#

	# get.
	def get(
		# the url (str) (#1).
		url=None,
		# the sended post data (dict) (#2).
		data={},
		# serialize output to dictionary.
		serialize=False,
	):
		
		# url.
		url = f"{Boolean(Requests.https).string(true='https', false='http')}://"+gfp.clean(f"{url}/", remove_double_slash=True, remove_last_slash=False, remove_first_slash=True)
		if len(url) >= len("https://https://") and String(url).first("https://https://") == "https://https://": url = str(String(url).remove_first("https://"))
		elif len(url) >= len("https://http://") and String(url).first("https://http://") == "https://http://": url = str(String(url).remove_first("https://"))
		elif len(url) >= len("http://https://") and String(url).first("http://https://") == "http://https://": url = str(String(url).remove_first("http://"))
		elif len(url) >= len("http://http://") and String(url).first("http://http://") == "http://http://": url = str(String(url).remove_first("http://"))
		if data != {}: url += Requests.encode(data)

		# request.
		original_request_object = __requests__.get(url, allow_redirects=Requests.allow_redirects)
		if original_request_object.status_code != 200:
			return Response.error(f"Invalid request ({url}) [{original_request_object.status_code}]: {original_request_object.text}")
		if serialize:
			try: response = Response.ResponseObject(json=original_request_object.json())
			except Exception as e: 
				return Response.error(f"Unable to serialize output: {original_request_object}, error: {e}.")
			return response
		return original_request_object


	# the restapi over ssh object class.
	class RestAPI(objects.Object):
		def __init__(self, 
			# the root url (optional).
			url=None,
			# the default data send with every request (will be appended to local data).
			data={
				"api_key":None,
			},
		):
			
			# defaults.
			objects.Object.__init__(self, traceback="Requests.RestAPI")
			
			# attributes.
			self.url = url
			self.data = data

			#
		def request(self, url="/", data={}):
			
			# data.
			for key,value in self.data.items(): 
				data[key] = value

			# url.
			if self.url != None: 
				url = gfp.clean(f"{self.url}/{url}/", remove_double_slash=True, remove_last_slash=False)
			
			# request.
			return Requests.get(serialize=True, url=url, data=data)

			#

		#

	#

#

#

==> dev0s-3.3.2.tar.gz: dev0s-3.3.2/dev0s/classes/requests/__init__.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# imports.
from dev0s.classes.response import *
from dev0s.classes import objects

# pip imports.
import urllib
import requests as __requests__

# the requests class.
class Requests():

	# variables.
	https = True
	allow_redirects = True

	# utils.
	def encode(data):
		return f"?{urllib.parse.urlencode(data)}"
		#

	# get.
	def get(
		# the url (str) (#1).
		url=None,
		# the sended post data (dict) (#2).
		data={},
		# serialize output to dictionary.
		serialize=False,
	):
		
		# url.
		url = f"{Boolean(Requests.https).string(true='https', false='http')}://"+gfp.clean(f"{url}/", remove_double_slash=True, remove_last_slash=False, remove_first_slash=True)
		if len(url) >= len("https://https://") and String(url).first("https://https://") == "https://https://": url = str(String(url).remove_first("https://"))
		elif len(url) >= len("https://http://") and String(url).first("https://http://") == "https://http://": url = str(String(url).remove_first("https://"))
		elif len(url) >= len("http://https://") and String(url).first("http://https://") == "http://https://": url = str(String(url).remove_first("http://"))
		elif len(url) >= len("http://http://") and String(url).first("http://http://") == "http://http://": url = str(String(url).remove_first("http://"))
		if data != {}: url += Requests.encode(data)

		# request.
		original_request_object = __requests__.get(url, allow_redirects=Requests.allow_redirects)
		if original_request_object.status_code != 200:
			return Response.error(f"Invalid request ({url}) [{original_request_object.status_code}]: {original_request_object.text}")
		if serialize:
			try: response = Response.ResponseObject(original_request_object.json())
			except Exception as e: 
				return Response.error(f"Unable to serialize output: {original_request_object}, error: {e}.")
			return response
		return original_request_object


	# the restapi over ssh object class.
	class RestAPI(objects.Object):
		def __init__(self, 
			# the root url (optional).
			url=None,
			# the default data send with every request (will be appended to local data).
			data={
				"api_key":None,
			},
		):
			
			# defaults.
			objects.Object.__init__(self, traceback="Requests.RestAPI")
			
			# attributes.
			self.url = url
			self.data = data

			#
		def request(self, url="/", data={}):
			
			# data.
			for key,value in self.data.items(): 
				data[key] = value

			# url.
			if self.url != None: 
				url = gfp.clean(f"{self.url}/{url}/", remove_double_slash=True, remove_last_slash=False)
			
			# request.
			return Requests.get(serialize=True, url=url, data=data)

			#

		#

	#

#

#
